@@ -12,7 +12,15 @@ from vessl.util.exception import InvalidOrganizationError
 class TestOrganization:
     organization_name = random_string()
 
-    @pytest.mark.order(index=1)
+    @classmethod
+    def teardown_class(cls):
+        print("teardown")
+        vessl.vessl_api.organization_delete_api(organization_name=cls.organization_name)
+
+    # Remove ordering because pytest executes all tests marked with orders (across all
+    # test files), causing teardown to be called for test classes containing these
+    # tests.
+    # @pytest.mark.order(index=1)
     def test_create_organization(self):
         vessl.create_organization(
             organization_name=self.organization_name,
@@ -34,9 +42,7 @@ def test_get_organization_name():
 
     organization_name = "org"
     assert (
-        vessl.organization._get_organization_name(
-            organization_name=organization_name
-        )
+        vessl.organization._get_organization_name(organization_name=organization_name)
         == organization_name
     )
 
