@@ -2,6 +2,7 @@ import functools
 import inspect
 
 import vessl
+import vessl.integration.tensorboard
 import vessl.internal
 from vessl._version import __VERSION__
 from vessl.util import logger
@@ -18,6 +19,7 @@ log = vessl.internal.log
 finish = vessl.internal.finish
 upload = vessl.internal.upload
 progress = vessl.internal.progress
+hp = vessl.internal.hyperparameters
 
 # Make API calls using `vessl_api`
 vessl_api = vessl.internal.api
@@ -103,6 +105,7 @@ from vessl.workspace import (
 
 # Expose others
 from vessl.util.image import Image  # isort:skip
+from vessl.util.audio import Audio  # isort:skip
 
 
 # Suppress all exceptions during SDK mode
@@ -130,7 +133,7 @@ for name, value in inspect.getmembers(
     vars()[name] = suppress_sdk_exception(value)
 
 # Other classes that the user may interact with
-user_classes = [Image]
+user_classes = [Image, Audio]
 for user_class in user_classes:
     for name, value in inspect.getmembers(
         user_class, predicate=lambda x: inspect.ismethod(x) or inspect.isfunction(x)
