@@ -93,6 +93,11 @@ def backup():
 
 
 @cli.vessl_command()
+@vessl_option(
+    "--workspace-id",
+    type=click.INT,
+    help="Workspace id to restore.",
+)
 @organization_name_option
-def restore():
-    restore_workspace()
+def restore(workspace_id: int):
+    restore_workspace(workspace_id)
