@@ -26,6 +26,10 @@ from vessl.internal.collector import (
     UserMetricCollector,
 )
 from vessl.internal.progress_updater import ProgressUpdater
+from vessl.internal.vessl_hyperparameters import (
+    Hyperparameters,
+    HyperparametersController,
+)
 from vessl.util import logger
 from vessl.util.api import VesslApi
 from vessl.util.audio import Audio
@@ -119,6 +123,7 @@ class VesslRun(object):
         "_collectors",
         "_sender",
         "_progress_updater",
+        "hyperparameters",
         "_experiment",
         "_logger",
         "_user_metric_collector",
@@ -129,6 +134,7 @@ class VesslRun(object):
     def __init__(self) -> None:
         self.api = VesslApi()
         self._experiment = self._get_experiment_from_environment()
+        self.hyperparameters = HyperparametersController(self.api, self._experiment)
         self._mode = MODE_NOT_STARTED if self._experiment is None else MODE_MANAGED
 
         self._user_metric_collector = UserMetricCollector()
@@ -152,7 +158,10 @@ class VesslRun(object):
             return None
 
     def _get_experiment_from_args(
-        self, experiment_name_or_number, message: str = None
+        self,
+        experiment_name_or_number,
+        message: str = None,
+        hyperparameters: Hyperparameters = None,
     ) -> ResponseExperimentInfo:
         """Get or create a local experiment
 
@@ -162,7 +171,7 @@ class VesslRun(object):
         if experiment_name_or_number is None:
             from vessl.experiment import create_local_experiment
 
-            experiment = create_local_experiment(message=message)
+            experiment = create_local_experiment(message=message, hyperparameters=hyperparameters)
             logger.debug(f"Created experiment {experiment.id}")
             return experiment
 
@@ -228,6 +237,7 @@ class VesslRun(object):
         experiment_name_or_number=None,
         message: str = None,
         tensorboard: bool = False,
+        hp: dict = None,
         **kwargs,
     ):
         """Main function to setup Vessl in a local setting
@@ -241,14 +251,22 @@ class VesslRun(object):
             tensorboard (bool): enable tensorboard integration. It is important to note
               that `vessl.init` must be called **before** initializing the writer
               (`tf.summary.create_file_writer` for TF2, SummaryWriter for PyTorch, etc).
+            hp (dict): hyperparameters
         """
         if self._mode == MODE_NOT_STARTED:
             print(f"Initializing a new experiment...")
             self.api.configure()
+
+            if hp:
+                self.hyperparameters.update_items(hp)
+
             self._experiment = self._get_experiment_from_args(
-                experiment_name_or_number, message
+                experiment_name_or_number,
+                message,
+                self.hyperparameters.as_list_of_dict(),
             )
             self._mode = MODE_LOCAL
+            self.hyperparameters.configure(self.api, self._experiment)
 
             print(
                 f"Connected to {self._experiment.name}.\n"
@@ -269,6 +287,11 @@ class VesslRun(object):
             self._sender = Sender(self.api, self._experiment.id, collectors)
             self._start()
 
+        if self._mode == MODE_MANAGED:
+            if hp is None:
+                return
+            self.hyperparameters.update(hp)
+
         if tensorboard:
             self._tensorboard_collector = integrate_tensorboard()
 
