@@ -347,7 +347,7 @@ def _configure_volume_mount_request_local_files(local_files: List[str], **kwargs
             os.path.join(tempfile.gettempdir(), f"{project.name}_{random_string()}.zip")
         )
         zipper = Zipper(zip_path, "w")
-        zipper.zip(cwd, zipper)
+        zipper.zip(cwd)
         zipper.close()
 
         uploaded = Uploader.upload(
