@@ -1,13 +1,14 @@
 import os
 import urllib.parse
+from datetime import datetime
 from pathlib import Path
 from typing import List
-from zipfile import ZipFile
 
 import click
 import inquirer
 import paramiko
 
+from openapi_client import CliWorkspaceBackupCreateAPIPayload
 from openapi_client.models import ResponseWorkspaceDetail, ResponseWorkspaceList
 from vessl import vessl_api
 from vessl.organization import _get_organization_name
@@ -15,11 +16,10 @@ from vessl.util.common import parse_time_to_ago
 from vessl.util.config import VesslConfigLoader
 from vessl.util.constant import (
     SSH_CONFIG_FORMAT,
-    SSH_CONFIG_PATH,
-    WORKSPACE_TEMP_ZIP_PATH,
-    WORKSPACE_ZIP_PATH,
+    SSH_CONFIG_PATH, TEMP_DIR,
 )
-from vessl.util.exception import InvalidWorkspaceError
+from vessl.util.exception import InvalidWorkspaceError, VesslException
+from vessl.util.random import random_string
 from vessl.util.zipper import Zipper
 from vessl.volume import copy_volume_file
 
@@ -63,61 +63,93 @@ def backup_workspace() -> None:
 
     workspace = read_workspace(workspace_id)
 
-    zipper = Zipper(WORKSPACE_TEMP_ZIP_PATH, "w")
-    zipper.zipdir(str(Path.home()), zipper)
+    filename = f'workspace-backup-{datetime.utcnow().strftime("%Y%m%d%H%M%S")}-{random_string()}.zip'
+    full_path = os.path.join(TEMP_DIR, filename)
+    home_dir = str(Path.home())
+    zipper = Zipper(full_path, "w")
+    zipper.zipdir(home_dir, include_dotfiles=True)
     zipper.close()
+    size = zipper.size()
+    print(f"Backup file size: {size}")
+    if size > 15 * 1024 * 1024 * 1024:
+        zipper.remove()
+        raise VesslException(f"{home_dir} is too large to backup.")
 
+    print("Uploading the backup file...")
     copy_volume_file(
         source_volume_id=None,
-        source_path=zipper.filename,
+        source_path=full_path,
         dest_volume_id=workspace.backup_volume_id,
-        dest_path=os.path.basename(zipper.filename),
+        dest_path=filename,
+    )
+    zipper.remove()
+
+    vessl_api.cli_workspace_backup_create_api(
+        workspace_id=workspace_id,
+        cli_workspace_backup_create_api_payload=CliWorkspaceBackupCreateAPIPayload(
+            filename=filename,
+        ),
     )
 
-    vessl_api.cli_workspace_backup_api(workspace_id=workspace_id)
 
-
-def restore_workspace() -> None:
+def restore_workspace(workspace_id: int = None) -> None:
     """Restore the home directory from the previous backup
 
     Should only be called inside a workspace.
     """
 
-    workspace_id = VesslConfigLoader().workspace
     if workspace_id is None:
-        raise InvalidWorkspaceError("Can only be called within a workspace.")
+        workspace_id = VesslConfigLoader().workspace
+        if workspace_id is None:
+            raise InvalidWorkspaceError("Can only be called within a workspace.")
 
-    workspace_list = list_workspaces(mine=True)
-    backup_workspaces = [w for w in workspace_list if w.last_backup_dt is not None]
-    if len(backup_workspaces) == 0:
-        raise click.ClickException("Available workspace backup not found.")
+        workspace_list = list_workspaces(mine=True)
+        backup_workspaces = [w for w in workspace_list if w.last_backup is not None]
+        if len(backup_workspaces) == 0:
+            raise click.ClickException("Available workspace backup not found.")
 
-    workspace = inquirer.prompt(
-        [
-            inquirer.List(
-                "question",
-                message="Select workspace",
-                choices=[
-                    (
-                        f"{w.name} (backup created {parse_time_to_ago(w.last_backup_dt)})",
-                        w,
-                    )
-                    for w in backup_workspaces
-                ],
-            )
-        ],
-        raise_keyboard_interrupt=True,
-    ).get("question")
+        workspace = inquirer.prompt(
+            [
+                inquirer.List(
+                    "question",
+                    message="Select workspace",
+                    choices=[
+                        (
+                            f"{w.name} (backup created {parse_time_to_ago(w.last_backup.created_dt)})",
+                            w,
+                        )
+                        for w in backup_workspaces
+                    ],
+                )
+            ],
+            raise_keyboard_interrupt=True,
+        ).get("question")
+    else:
+        workspace = read_workspace(workspace_id=workspace_id)
+        if workspace.last_backup is None:
+            raise click.ClickException("This workspace does not have any backup.")
 
+    dest_path = os.path.join(TEMP_DIR, "workspace-backup.zip")
+    print("Downloading the backup file...")
     copy_volume_file(
         source_volume_id=workspace.backup_volume_id,
-        source_path=WORKSPACE_ZIP_PATH,
+        source_path=workspace.last_backup.filename,
         dest_volume_id=None,
-        dest_path=WORKSPACE_TEMP_ZIP_PATH,
+        dest_path=dest_path,
     )
 
-    z = ZipFile(WORKSPACE_TEMP_ZIP_PATH)
-    z.extractall(str(Path.home()))
+    zipper = Zipper(dest_path, "r")
+    size = zipper.size()
+    print(f"Backup file size: {size}")
+    extract_path = str(Path.home())
+    if size > 15 * 1024 * 1024 * 1024:
+        extract_path = os.path.join(TEMP_DIR, "workspace-backup")
+    print("Extracting...")
+    zipper.extractall(extract_path)
+    if size > 15 * 1024 * 1024 * 1024:
+        print(f"Restored to {extract_path} since the size of the backup file is larger than 15Gi.")
+    zipper.close()
+    zipper.remove()
 
 
 def connect_workspace_ssh(private_key_path: str, **kwargs) -> None:
